bayespy.inference.vmp.nodes.gaussian_markov_chain.GaussianMarkovChainMoments
============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian_markov_chain

.. autoclass:: GaussianMarkovChainMoments

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianMarkovChainMoments.add_converter
      ~GaussianMarkovChainMoments.compute_dims_from_values
      ~GaussianMarkovChainMoments.compute_fixed_moments
      ~GaussianMarkovChainMoments.get_converter
   
   

   
   
   